from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2
from omni.pro.protos.v1.rules import country_pb2 as _country_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class DeliveryLocality(_message.Message):
    __slots__ = ["id", "name", "country", "code_collection", "items", "active", "object_audit"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    CODE_COLLECTION_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    country: _country_pb2.Country
    code_collection: str
    items: _struct_pb2.ListValue
    active: _wrappers_pb2.BoolValue
    object_audit: _base_pb2.ObjectAudit
    def __init__(
        self,
        id: _Optional[str] = ...,
        name: _Optional[str] = ...,
        country: _Optional[_Union[_country_pb2.Country, _Mapping]] = ...,
        code_collection: _Optional[str] = ...,
        items: _Optional[_Union[_struct_pb2.ListValue, _Mapping]] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class DeliveryLocalityCreateRequest(_message.Message):
    __slots__ = ["name", "country_id", "code_collection", "items", "context"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_ID_FIELD_NUMBER: _ClassVar[int]
    CODE_COLLECTION_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    name: str
    country_id: str
    code_collection: str
    items: _containers.RepeatedScalarFieldContainer[str]
    context: _base_pb2.Context
    def __init__(
        self,
        name: _Optional[str] = ...,
        country_id: _Optional[str] = ...,
        code_collection: _Optional[str] = ...,
        items: _Optional[_Iterable[str]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class DeliveryLocalityCreateResponse(_message.Message):
    __slots__ = ["delivery_locality", "response_standard"]
    DELIVERY_LOCALITY_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    delivery_locality: DeliveryLocality
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        delivery_locality: _Optional[_Union[DeliveryLocality, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class DeliveryLocalityReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "id", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    id: str
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class DeliveryLocalityReadResponse(_message.Message):
    __slots__ = ["delivery_localities", "meta_data", "response_standard"]
    DELIVERY_LOCALITIES_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    delivery_localities: _containers.RepeatedCompositeFieldContainer[DeliveryLocality]
    meta_data: _base_pb2.MetaData
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        delivery_localities: _Optional[_Iterable[_Union[DeliveryLocality, _Mapping]]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class DeliveryLocalityUpdateRequest(_message.Message):
    __slots__ = ["delivery_locality", "context"]
    DELIVERY_LOCALITY_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    delivery_locality: DeliveryLocality
    context: _base_pb2.Context
    def __init__(
        self,
        delivery_locality: _Optional[_Union[DeliveryLocality, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class DeliveryLocalityUpdateResponse(_message.Message):
    __slots__ = ["delivery_locality", "response_standard"]
    DELIVERY_LOCALITY_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    delivery_locality: DeliveryLocality
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        delivery_locality: _Optional[_Union[DeliveryLocality, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class DeliveryLocalityDeleteRequest(_message.Message):
    __slots__ = ["id", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: str
    context: _base_pb2.Context
    def __init__(
        self, id: _Optional[str] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class DeliveryLocalityDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class AddTerritoryMatrixValueRequest(_message.Message):
    __slots__ = ["delivery_locality_id", "territory_matrix_values", "context"]
    DELIVERY_LOCALITY_ID_FIELD_NUMBER: _ClassVar[int]
    TERRITORY_MATRIX_VALUES_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    delivery_locality_id: str
    territory_matrix_values: _struct_pb2.ListValue
    context: _base_pb2.Context
    def __init__(
        self,
        delivery_locality_id: _Optional[str] = ...,
        territory_matrix_values: _Optional[_Union[_struct_pb2.ListValue, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class AddTerritoryMatrixValueResponse(_message.Message):
    __slots__ = ["delivery_locality", "response_standard"]
    DELIVERY_LOCALITY_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    delivery_locality: DeliveryLocality
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        delivery_locality: _Optional[_Union[DeliveryLocality, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class RemoveTerritoryMatrixValueRequest(_message.Message):
    __slots__ = ["delivery_locality_id", "territory_matrix_values", "context"]
    DELIVERY_LOCALITY_ID_FIELD_NUMBER: _ClassVar[int]
    TERRITORY_MATRIX_VALUES_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    delivery_locality_id: str
    territory_matrix_values: _struct_pb2.ListValue
    context: _base_pb2.Context
    def __init__(
        self,
        delivery_locality_id: _Optional[str] = ...,
        territory_matrix_values: _Optional[_Union[_struct_pb2.ListValue, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class RemoveTerritoryMatrixValueResponse(_message.Message):
    __slots__ = ["delivery_locality", "response_standard"]
    DELIVERY_LOCALITY_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    delivery_locality: DeliveryLocality
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        delivery_locality: _Optional[_Union[DeliveryLocality, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...
